@@ -264,7 +264,7 @@ def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric =
 
 		return resp_obj
 
-def analyze(img_path, actions = ['emotion', 'age', 'gender', 'race'] , models = {}, enforce_detection = True, detector_backend = 'opencv', prog_bar = True):
+def analyze(img_path, actions = ('emotion', 'age', 'gender', 'race') , models = None, enforce_detection = True, detector_backend = 'opencv', prog_bar = True):
 
 	"""
 	This function analyzes facial attributes including age, gender, emotion and race
@@ -272,9 +272,9 @@ def analyze(img_path, actions = ['emotion', 'age', 'gender', 'race'] , models =
 	Parameters:
 		img_path: exact image path, numpy array or base64 encoded image could be passed. If you are going to analyze lots of images, then set this to list. e.g. img_path = ['img1.jpg', 'img2.jpg']
 
-		actions (list): The default is ['age', 'gender', 'emotion', 'race']. You can drop some of those attributes.
+		actions (tuple): The default is ('age', 'gender', 'emotion', 'race'). You can drop some of those attributes.
 
-		models: facial attribute analysis models are built in every call of analyze function. You can pass pre-built models to speed the function up.
+		models: (Optional[dict]) facial attribute analysis models are built in every call of analyze function. You can pass pre-built models to speed the function up.
 
 			models = {}
 			models['age'] = DeepFace.build_model('Age')
@@ -317,6 +317,10 @@ def analyze(img_path, actions = ['emotion', 'age', 'gender', 'race'] , models =
 
 	"""
 
+	actions = list(actions)
+	if not models:
+		models = {}
+
 	img_paths, bulkProcess = functions.initialize_input(img_path)
 
 	#---------------------------------
@@ -796,7 +800,7 @@ def stream(db_path = '', model_name ='VGG-Face', detector_backend = 'opencv', di
 	realtime.analysis(db_path, model_name, detector_backend, distance_metric, enable_face_analysis
 						, source = source, time_threshold = time_threshold, frame_threshold = frame_threshold)
 
-def detectFace(img_path, detector_backend = 'opencv', enforce_detection = True, align = True):
+def detectFace(img_path, target_size = (224, 224), detector_backend = 'opencv', enforce_detection = True, align = True):
 
 	"""
 	This function applies pre-processing stages of a face recognition pipeline including detection and alignment
@@ -810,11 +814,11 @@ def detectFace(img_path, detector_backend = 'opencv', enforce_detection = True,
 		deteced and aligned face in numpy format
 	"""
 
-	img = functions.preprocess_face(img = img_path, detector_backend = detector_backend
+	img = functions.preprocess_face(img = img_path, target_size = target_size, detector_backend = detector_backend
 		, enforce_detection = enforce_detection, align = align)[0] #preprocess_face returns (1, 224, 224, 3)
 	return img[:, :, ::-1] #bgr to rgb
 
 #---------------------------
 #main
 
-functions.initializeFolder()
+functions.initialize_folder()
