@@ -3,6 +3,8 @@ from pathlib import Path
 import gdown
 from functools import partial
 
+from deepface.commons import functions
+
 import tensorflow as tf
 tf_version = int(tf.__version__.split(".")[0])
 
@@ -555,7 +557,7 @@ def loadModel(url = 'https://github.com/serengil/deepface_models/releases/downlo
 
 	#-----------------------------------
 
-	home = str(Path.home())
+	home = functions.get_deepface_home()
 
 	if os.path.isfile(home+'/.deepface/weights/facenet_weights.h5') != True:
 		print("facenet_weights.h5 will be downloaded...")
