@@ -8,6 +8,8 @@ def build_model():
 
 def detect_face(face_detector, img, align = True):
 
+	resp = []
+
 	detected_face = None
 	img_region = [0, 0, img.shape[0], img.shape[1]]
 
@@ -15,16 +17,18 @@ def detect_face(face_detector, img, align = True):
 	detections = face_detector.detect_faces(img_rgb)
 
 	if len(detections) > 0:
-		detection = detections[0]
-		x, y, w, h = detection["box"]
-		detected_face = img[int(y):int(y+h), int(x):int(x+w)]
-		img_region = [x, y, w, h]
 
-		keypoints = detection["keypoints"]
-		left_eye = keypoints["left_eye"]
-		right_eye = keypoints["right_eye"]
+		for detection in detections:
+			x, y, w, h = detection["box"]
+			detected_face = img[int(y):int(y+h), int(x):int(x+w)]
+			img_region = [x, y, w, h]
 
-		if align:
-			detected_face = FaceDetector.alignment_procedure(detected_face, left_eye, right_eye)
+			if align:
+				keypoints = detection["keypoints"]
+				left_eye = keypoints["left_eye"]
+				right_eye = keypoints["right_eye"]
+				detected_face = FaceDetector.alignment_procedure(detected_face, left_eye, right_eye)
 
-	return detected_face, img_region
+			resp.append((detected_face, img_region))
+
+	return resp
